==> kbibtex-0.7.tar.xz: kbibtex-0.7/src/networking/onlinesearch/onlinesearchacmportal.h <==
/***************************************************************************
 *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/
#ifndef KBIBTEX_ONLINESEARCH_ACMPORTAL_H
#define KBIBTEX_ONLINESEARCH_ACMPORTAL_H

#include <QByteArray>

#include "onlinesearchabstract.h"

class QSpinBox;
class KComboBox;
class KLineEdit;

/**
 * @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
 */
class KBIBTEXNETWORKING_EXPORT OnlineSearchAcmPortal : public OnlineSearchAbstract
{
    Q_OBJECT

public:
    explicit OnlineSearchAcmPortal(QWidget *parent);
    ~OnlineSearchAcmPortal();

    virtual void startSearch();
    virtual void startSearch(const QMap<QString, QString> &query, int numResults);
    virtual QString label() const;
    virtual OnlineSearchQueryFormAbstract *customWidget(QWidget *parent);
    virtual KUrl homepage() const;

public slots:
    void cancel();

protected:
    virtual QString favIconUrl() const;

private slots:
    void doneFetchingStartPage();
    void doneFetchingSearchPage();
    void doneFetchingCitation();
    void doneFetchingBibTeX();

private:
    class OnlineSearchAcmPortalPrivate;
    OnlineSearchAcmPortalPrivate *d;
};

#endif // KBIBTEX_ONLINESEARCH_ACMPORTAL_H

==> kbibtex-0.9.3.2.tar.xz: kbibtex-0.9.3.2/src/networking/onlinesearch/onlinesearchacmportal.h <==
/***************************************************************************
 *   Copyright (C) 2004-2022 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
 ***************************************************************************/

#ifndef KBIBTEX_ONLINESEARCH_ACMPORTAL_H
#define KBIBTEX_ONLINESEARCH_ACMPORTAL_H

#include <QByteArray>

#include "onlinesearchabstract.h"

class QSpinBox;
class KComboBox;
class KLineEdit;

/**
 * @author Thomas Fischer <fischer@unix-ag.uni-kl.de>
 */
class KBIBTEXNETWORKING_EXPORT OnlineSearchAcmPortal : public OnlineSearchAbstract
{
    Q_OBJECT

public:
    explicit OnlineSearchAcmPortal(QObject *parent);
    ~OnlineSearchAcmPortal() override;

    void startSearch(const QMap<QString, QString> &query, int numResults) override;
    QString label() const override;
    QUrl homepage() const override;

protected:
    QString favIconUrl() const override;

private slots:
    void doneFetchingStartPage();
    void doneFetchingSearchPage();
    void doneFetchingJSON();

private:
    class OnlineSearchAcmPortalPrivate;
    OnlineSearchAcmPortalPrivate *d;
};

#endif // KBIBTEX_ONLINESEARCH_ACMPORTAL_H
